@@ -9,6 +9,14 @@
 #
 # See README.txt for more details.
 
+''' securely save HTTP and SMTP authentication details
+mercurial_keyring is a Mercurial extension used to securely save
+HTTP and SMTP authentication passwords in password databases (Gnome
+Keyring, KDE KWallet, OSXKeyChain, specific solutions for Win32 and
+command line). This extension uses and wraps services of the keyring
+library.
+'''
+
 from mercurial import hg, repo, util
 from mercurial.i18n import _
 try:
